@@ -48,8 +48,16 @@ class ConsumirInstalaccionController extends Controller
       }elseif (strtolower($proveedor) == "microserv") {
          $destinatario = ["isantelices@microserv.cl"];
          Mail::to($destinatario)->send(new TestMail($details,$sc,$nSerie,$size));
-      } elseif (strtolower($proveedor) == "kyocera") {
+      }elseif (strtolower($proveedor) == "imprecorp") {
+         $destinatario = ["juan.pinto@imprecorp.cl"];
+         Mail::to($destinatario)->send(new TestMail($details,$sc,$nSerie,$size));
+      }elseif (strtolower($proveedor) == "prueba") {
+         $destinatario = ["cristobal@globati.com","ariel@globati.com"];
+         Mail::to($destinatario)->send(new TestMail($details,$sc,$nSerie,$size));
       }
+       elseif (strtolower($proveedor) == "kyocera") {
+      }
+      
       return "ok";
    }
    /**
@@ -417,7 +425,7 @@ class ConsumirInstalaccionController extends Controller
                'timeout'  => 2.0,
             ]);
 
-           /* 
+           
            $response = $client->request('GET', 'updatetrackerinsbchile', [
 
                'form_params' => [
@@ -465,7 +473,7 @@ class ConsumirInstalaccionController extends Controller
                ]
 
 
-            ]); */
+            ]); 
          }
          $datos_accesorios = DB::table('checklist_accesorios')
             ->join('accesorios', 'accesorios.id', '=', 'checklist_accesorios.id_accesorio')
@@ -547,12 +555,12 @@ class ConsumirInstalaccionController extends Controller
          $url = session('url_cordinadora');
          $correo = $this->sendEmail($fecha_inicio, $client, $contacto, $direccion, $comuna, $region, $tipo_visita, $descripcionCliente, $sc, $nSerie, $modelo, $contadorBn, $contadorC, $estadoOpcion, $estadoInstalacion, $observacionTecnico, $proveedor, $size, $idasig);
          if (!empty($url)) {
-            //return redirect($url)->with('mensaje', 'Respuestas Enviada a Kyocera'); // Cambio Pablo: 04-01-2023
-            return redirect($url)->with('mensaje', 'Guardado - [Sin comunicacion con web service Kyocera]');
+            return redirect($url)->with('mensaje', 'Actualizado'); // Cambio Pablo: 04-01-2023
+            //return redirect($url)->with('mensaje', 'Guardado - [Sin comunicacion con web service Kyocera]');
          } else {
-            //return redirect('/home')->with('mensaje_error', 'Respuestas Enviada a Kyocera');
+           // return redirect('/home')->with('mensaje_error', 'Respuestas Enviada a Kyocera');
             // Cambio Pablo: 04-01-2023
-            return redirect('/home')->with('mensaje_error', 'Guardado - [Sin comunicacion con web service Kyocera]');
+           return redirect('/home')->with('mensaje_error', 'Guardado - [Sin comunicacion con web service Kyocera]');
          }
 
 
